FALSE = 'False'
CLASS = 'class'
FINALLY = 'finally'
IS = 'is'
RETURN = 'return'
NONE = 'None'
CONTINUE = 'continue'
FOR = 'for'
LAMBDA = 'lambda'
TRY = 'try'
TRUE = 'True'
DEF = 'def'
FROM = 'from'
NONLOCAL = 'nonlocal'
WHILE = 'while'
AND = 'and'
DEL = 'del'
GLOBAL = 'global'
NOT = 'not'
WITH = 'with'
AS = 'as'
ELIF = 'elif'
IF = 'if'
OR = 'or'
YIELD = 'yield'
ASSERT = 'assert'
ELSE = 'else'
IMPORT = 'import'
PASS = 'pass'
BREAK = 'break'
EXCEPT = 'except'
IN = 'in'
RAISE = 'raise'

RESERVED = [
    FALSE,
    CLASS,
    FINALLY,
    IS,
    RETURN,
    NONE,
    CONTINUE,
    FOR,
    LAMBDA,
    TRY,
    TRUE,
    DEF,
    FROM,
    NONLOCAL,
    WHILE,
    AND,
    DEL,
    GLOBAL,
    NOT,
    WITH,
    AS,
    ELIF,
    IF,
    OR,
    YIELD,
    ASSERT,
    ELSE,
    IMPORT,
    PASS,
    BREAK,
    EXCEPT,
    IN,
    RAISE,
    "+",
    "-",
    "/",
    "*",
    "+=",
    "-=",
    "/=",
    "*=",
    "**",
    "%",
    "!",
    "@",
    "^",
    "&",
    "(",
    ")",
    "=",
    "'",
    "\"",
    "|",
    ">",
    ">=",
    "<",
    "<=",
    ",",
    "!=",
    "==",
    ":",
    '.'
]
